"""Compute backends: v1 recompute (golden reference); v2 incremental deferred."""

from abkit.compute.recompute_backend import RecomputeBackend, dialect_of

__all__ = ["RecomputeBackend", "dialect_of"]
